gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[libeufin] 02/02: rfc8959


From: gnunet
Subject: [libeufin] 02/02: rfc8959
Date: Mon, 25 Sep 2023 14:18:14 +0200

This is an automated email from the git hooks/post-receive script.

sebasjm pushed a commit to branch master
in repository libeufin.

commit 6b57f220fcc33d77db825524c8816d511614bac5
Author: Sebastian <sebasjm@gmail.com>
AuthorDate: Mon Sep 25 09:18:06 2023 -0300

    rfc8959
---
 bank/src/main/kotlin/tech/libeufin/bank/helpers.kt | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/bank/src/main/kotlin/tech/libeufin/bank/helpers.kt 
b/bank/src/main/kotlin/tech/libeufin/bank/helpers.kt
index 04d334c3..34a966d8 100644
--- a/bank/src/main/kotlin/tech/libeufin/bank/helpers.kt
+++ b/bank/src/main/kotlin/tech/libeufin/bank/helpers.kt
@@ -85,17 +85,17 @@ fun doBasicAuth(db: Database, encodedCredentials: String): 
Customer? {
 
 /**
  * This function takes a prefixed Bearer token, removes the
  * bearer-token:-prefix and returns it.  Returns null, if the
  * input is invalid.
  */
 private fun splitBearerToken(tok: String): String? {
     val tokenSplit = tok.split(":", limit = 2)
     if (tokenSplit.size != 2) return null
-    if (tokenSplit[0] != "bearer-token") return null
+    if (tokenSplit[0] != "secret-token") return null
     return tokenSplit[1]
 }
 
 /* Performs the bearer-token authentication.  Returns the
  * authenticated customer on success, null otherwise. */
 fun doTokenAuth(
     db: Database,
@@ -85,17 +85,17 @@ fun doBasicAuth(db: Database, encodedCredentials: String): 
 /**
  * This function takes a prefixed Bearer token, removes the
- * bearer-token:-prefix and returns it.  Returns null, if the
+ * secret-token:-prefix and returns it.  Returns null, if the
  * input is invalid.
  */
@@ -85,17 +85,17 @@ fun doBasicAuth(db: Database, encodedCredentials: String): 
 }
 
-/* Performs the bearer-token authentication.  Returns the
+/* Performs the secret-token authentication.  Returns the
  * authenticated customer on success, null otherwise. */
 fun doTokenAuth(

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]